#
# spec file for package python3-efl
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define efl_version 1.20.0

Name:           python3-efl
Version:        1.20.0
Release:        lp150.2.7
Summary:        Python bindings of efl
License:        GPL-3.0 and LGPL-3.0
Group:          Development/Libraries/Python
Url:            http://enlightenment.org
Source:         python-efl-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  python3-Cython
BuildRequires:  python3-Sphinx
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(dbus-python)
BuildRequires:  pkgconfig(ecore)
BuildRequires:  pkgconfig(edje)
BuildRequires:  pkgconfig(elementary) >= %efl_version
BuildRequires:  pkgconfig(emotion)
BuildRequires:  pkgconfig(eo) >= %efl_version
BuildRequires:  pkgconfig(evas)
BuildRequires:  pkgconfig(python)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif

%description
Python bindings of the enlightenment foundation libraries (efl)

%package doc
Summary:        Documentation for python-efl
Group:          Documentation/HTML
BuildRequires:  python-sphinx

%description doc
HTML formated documentation for python-efl module.

%package examples
Summary:        Examples of python-efl usage
Group:          Documentation/Other

%description examples
Some examples of usage of python-efl.

%prep
%setup -q -n python-efl-%{version}
# drop build date from doc to fix build-compare
sed -i "s/\(html_last_updated_fmt = \).*/\\1None/" ./doc/conf.py

%build
export CFLAGS="$CFLAGS -Wno-declaration-after-statement"
python3 setup.py build -g
python3 setup.py build_doc

%install
export DISABLE_CYTHON=1

# module itself
python3 setup.py install --prefix="%{_prefix}" --root=%{buildroot}

# documentation
install -m 0755 -d "%{buildroot}/%{_docdir}/%{name}"
cp -R build/sphinx/html "%{buildroot}/%{_docdir}/%{name}"
rm "%{buildroot}/%{_docdir}/%{name}"/html/.buildinfo
%if 0%{?suse_version}
%fdupes -s "%{buildroot}/%{_docdir}/%{name}"
%endif

# examples
install -m 0755 -d "%{buildroot}/%{_datadir}/%{name}"
cp -R examples/  "%{buildroot}/%{_datadir}/%{name}/"
mkdir -p %{buildroot}/%{_docdir}/%{name}
cp -pr COPYING %{buildroot}/%{_docdir}/%{name}/
cp -pr COPYING.LESSER %{buildroot}/%{_docdir}/%{name}/
cp -pr AUTHORS %{buildroot}/%{_docdir}/%{name}/

%files
%defattr(-,root,root)
%{_libdir}/python*/*/*
%{_docdir}/%{name}/
%exclude %{_docdir}/%{name}/html/

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}/html/

%files examples
%defattr(-,root,root)
%{_datadir}/%{name}

%changelog
* Tue Sep  5 2017 sflees@suse.de
- i586 builds are working again, reenable them
- update the efl version requirement to be correct
* Wed Aug 23 2017 sflees@suse.de
- Sync with efl 1.20
* Tue Jun 27 2017 lnussel@suse.de
- Exclude x86, cc1 uses too much memory atm
* Thu Jun 22 2017 sflees@suse.de
- Add a _constraints file to fix out of mem issues
* Wed May 17 2017 sflees@suse.de
- Update to 1.19.0
  * changes in line with 1.19.X changes in efl
* Wed Aug 31 2016 sflees@suse.de
- Another attempt at python3 - Removes python2 support
* Sat Nov 14 2015 simon@simotek.net
- 1.16.0 pre release will add full changes with release
* Fri Aug 21 2015 simon@simotek.net
- Add COPYING.* AUTHORS to package
* Sat Aug 15 2015 simon@simotek.net
- Bindings update to efl 1.15.x
  Fixes:
    elm.Entry: Fixed name of the callback_rejected_del function
    Fixed build on OSX
    Fixed build when ecore-x is not available
    Fixed module init from embedded interpreter
  Changes:
    Elm: Unify modules into a monolithic module
  Additions:
    elm.Configuration.transition_duration_factor
    elm.Window.autohide
    elm.ELM_POLICY_QUIT_LAST_WINDOW_HIDDEN
    elm.Entry.callback_context_open_add/del
    elm.ELM_FOCUS_MOVE_POLICY_KEY_ONLY
    elm.Object.focus_move_policy
    elm.Scrollable.wheel_disabled
    evas.Textblock.obstacle_add
    evas.Textblock.obstacle_del
    evas.Textblock.obstacles_update
    evas.EVAS_CALLBACK_CANVA_VIEWPORT_RESIZE
* Thu May  7 2015 simon@simotek.net
- Bindings updated to efl 1.14.X
* Mon Feb 16 2015 simon@simotek.net
- Bindings updated to match efl 1.13.x
* Fri Jan  9 2015 simon@simotek.net
- Bindings updated to match efl 1.12.x
* Tue Sep 16 2014 simon@simotek.net
- bump to 1.11.0
  * * Re enabled cython building **
  No new features upstream just following efl changes
* Mon Aug 18 2014 simon@simotek.net
- Disabled Cython with env var for this release as the upstream tar was broken.
  It was missing .pxd files this has been fixed for the next release.
* Sun Jun  1 2014 sleep_walker@suse.cz
- bump to 1.10.0 (but missing any short changelog)
- correct all provides and obsoletes
* Wed Apr  9 2014 simon@simotek.net
- version 1.9.0
  Release Notes:
  No major changes have been made since the last 1.8 release. All the new
  features of efl and elementary 1.9 has been ported and the usual has been
  done in fixing bugs and optimizing speed. (see **changes.html** in the
  tarball for the full list of changes)
* Tue Dec 17 2013 sleep_walker@suse.cz
- change to use pkgconfig dependencies
- beutify spec a bit
* Mon Dec  9 2013 sleep_walker@suse.cz
- let there by python-efl!
